@@ -18,16 +18,14 @@ class CountdownTimer():
     total_seconds: int = 0 # Total seconds for one repeat
     total_seconds_start_value: int = 10 # Start value of total_seconds for one report (total_seconds will change on seconds_decrements repeats)
     seconds_passed: int = 0 # Seconds passed from the start
-    seconds_decrements: Set[int] = {100, 200, 300, 400, 500, 700, 900} # Repeats after which total_seconds will be decreased by 1
-
-    timer_changed_event: Event = None # Used to notify people connected via WebSockets
+    seconds_decrements: Set[int] = {50, 100, 150, 200, 250, 500, 700} # Repeats after which total_seconds will be decreased by 1
 
     repeat: int = 0 # Current repeat
     total_repeats: int = 1000 # Total number of repeats
 
     breaks: Set[int] = {100, 200, 300, 400, 500, 600, 700, 800, 900} # Repeats after which there will be a break
     break_duration: int = 120 # How many seconds a break will last
-    mini_breaks: Set[int] = {50, 150, 250, 350, 450, 550, 650, 750, 850, 950} # Repeats after which there will be a mini-break
+    mini_breaks: Set[int] = {50, 150, 250} # Repeats after which there will be a mini-break to prepare for total_seconds change
     mini_break_duration: int = 10 # How many seconds a mini-break will last
 
     is_running: bool = False # Is CountdownTimer running
@@ -35,24 +33,26 @@ class CountdownTimer():
     is_paused: bool = False # Is CountdownTimer paused
 
     countdown_data_json: str = '{}' # JSON with current CountdownTimer state data
+    timer_changed_event: Event = None # Used to notify people connected via WebSockets
 
     @classmethod
     def update_json(cls) -> None:
         cls.countdown_data_json = json.dumps({
-            'seconds' : CountdownTimer.seconds,
-            'timestamp' : CountdownTimer.timestamp,
-            'total_seconds' : CountdownTimer.total_seconds,
-            'seconds_passed' : CountdownTimer.seconds_passed,
-            'seconds_decrements' : CountdownTimer.seconds_decrements,
-            'repeat' : CountdownTimer.repeat,
-            'total_repeats' : CountdownTimer.total_repeats,
-            'breaks' : CountdownTimer.breaks,
-            'break_duration' : CountdownTimer.break_duration,
-            'mini_breaks' : CountdownTimer.mini_breaks,
-            'mini_break_duration' : CountdownTimer.mini_break_duration,
-            'is_running' : CountdownTimer.is_running,
-            'is_paused' : CountdownTimer.is_paused,
-            'is_break' : CountdownTimer.is_break
+            'seconds' : cls.seconds,
+            'timestamp' : cls.timestamp,
+            'total_seconds' : cls.total_seconds,
+            'total_seconds_start_value' : cls.total_seconds_start_value,
+            'seconds_passed' : cls.seconds_passed,
+            'seconds_decrements' : cls.seconds_decrements,
+            'repeat' : cls.repeat,
+            'total_repeats' : cls.total_repeats,
+            'breaks' : cls.breaks,
+            'break_duration' : cls.break_duration,
+            'mini_breaks' : cls.mini_breaks,
+            'mini_break_duration' : cls.mini_break_duration,
+            'is_running' : cls.is_running,
+            'is_paused' : cls.is_paused,
+            'is_break' : cls.is_break
         }, cls=SetEncoder)
 
     @classmethod
@@ -72,7 +72,6 @@ class CountdownTimer():
     @classmethod
     def notify_timer_changed(cls) -> None:
         if cls.timer_changed_event:
-            cls.update_json()
             cls.timer_changed_event.set()
             cls.timer_changed_event.clear()
 
@@ -132,10 +131,12 @@ class CountdownTimer():
         cls.is_running = True
         cls.is_break = False
         cls.is_paused = False
+        cls.update_json()
 
         # Start countdown loop
         cls.scheduler.remove_all_jobs()
         cls.scheduler.add_job(cls.countdown_loop, 'interval', seconds=1)
+        cls.scheduler.add_job(cls.notify_timer_changed, 'interval', seconds=10)
 
         # Notify WebSockets subscribers about change (start/restart)
         cls.notify_timer_changed()
@@ -168,6 +169,7 @@ class CountdownTimer():
         cls.is_running = False
         cls.is_break = False
         cls.is_paused = False
+        cls.update_json()
 
         # Notify WebSockets subscribers about change (stop)
         cls.notify_timer_changed()
@@ -182,6 +184,7 @@ class CountdownTimer():
         # Stop countdown loop
         cls.scheduler.remove_all_jobs()
         cls.is_paused = True
+        cls.update_json()
 
         # Notify WebSockets subscribers about change (pause)
         cls.notify_timer_changed()
@@ -196,7 +199,9 @@ class CountdownTimer():
         # Start countdown loop
         cls.scheduler.remove_all_jobs()
         cls.scheduler.add_job(cls.countdown_loop, 'interval', seconds=1)
+        cls.scheduler.add_job(cls.notify_timer_changed, 'interval', seconds=10)
         cls.is_paused = False
+        cls.update_json()
 
         # Notify WebSockets subscribers about change (resume)
         cls.notify_timer_changed()
