@@ -14,11 +14,11 @@ class WGCountdownTimer():
         cls.server = Starlette()
 
         # HTTP Routes for CountdownTimer actions
-        cls.server.add_route('/v0/countdown/start', CountdownTimerActionEndpoints.start, methods=['POST'])
-        cls.server.add_route('/v0/countdown/reset', CountdownTimerActionEndpoints.reset, methods=['POST'])
-        cls.server.add_route('/v0/countdown/stop', CountdownTimerActionEndpoints.stop, methods=['POST'])
-        cls.server.add_route('/v0/countdown/pause', CountdownTimerActionEndpoints.pause, methods=['POST'])
-        cls.server.add_route('/v0/countdown/resume', CountdownTimerActionEndpoints.resume, methods=['POST'])
+        cls.server.add_route('/v0/countdown/start', CountdownTimerActionEndpoints.start, methods=['GET'])
+        cls.server.add_route('/v0/countdown/reset', CountdownTimerActionEndpoints.reset, methods=['GET'])
+        cls.server.add_route('/v0/countdown/stop', CountdownTimerActionEndpoints.stop, methods=['GET'])
+        cls.server.add_route('/v0/countdown/pause', CountdownTimerActionEndpoints.pause, methods=['GET'])
+        cls.server.add_route('/v0/countdown/resume', CountdownTimerActionEndpoints.resume, methods=['GET'])
 
         # HTTP Routes for Client-Side JavaScript CountdownTimer script
         cls.server.add_route('/v0/client/countdown.js', CountdownTimerFilesEndpoints.countdown_js, methods=['GET'])
